Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(59)

Unified Diff: LayoutTests/svg/css/script-tests/svg-attribute-parser-mode.js

Issue 114373004: Remove the SVGColor and SVGPaint DOM interfaces (were deprecated). (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: text diff fix Created 7 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: LayoutTests/svg/css/script-tests/svg-attribute-parser-mode.js
diff --git a/LayoutTests/svg/css/script-tests/svg-attribute-parser-mode.js b/LayoutTests/svg/css/script-tests/svg-attribute-parser-mode.js
index 6ea8abb8c07b1222493b0dad8833f55443ef7810..1a83b91d4b4a36be56aac3b84a027d0cb8776ca5 100644
--- a/LayoutTests/svg/css/script-tests/svg-attribute-parser-mode.js
+++ b/LayoutTests/svg/css/script-tests/svg-attribute-parser-mode.js
@@ -12,55 +12,55 @@ rootSVGElement.appendChild(rect);
// Testing 'fill'
-// The default for fill is #000000.
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "#000000");
+// The default for fill is rgb(0, 0, 0).
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "rgb(0, 0, 0)");
// Set the fill color to green.
rect.setAttribute("fill", "green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "#008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "rgb(0, 128, 0)");
// Set following colors should be invalid.
rect.setAttribute("fill", "f00");
shouldBeNull("document.defaultView.getComputedStyle(rect, null).fill");
// Reset to green.
rect.setAttribute("fill", "green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "#008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "rgb(0, 128, 0)");
rect.setAttribute("fill", "ff00");
shouldBeNull("document.defaultView.getComputedStyle(rect, null).fill");
// Reset to green.
rect.setAttribute("fill", "green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "#008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "rgb(0, 128, 0)");
rect.setAttribute("fill", "ff0000");
shouldBeNull("document.defaultView.getComputedStyle(rect, null).fill");
// Reset to green.
rect.setAttribute("fill", "green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "#008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "rgb(0, 128, 0)");
rect.setAttribute("fill", "ff00");
shouldBeNull("document.defaultView.getComputedStyle(rect, null).fill");
// Reset to green.
rect.setAttribute("fill", "green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "#008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "rgb(0, 128, 0)");
rect.setAttribute("fill", "");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "#000000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "rgb(0, 0, 0)");
// Reset to green.
rect.setAttribute("fill", "green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "#008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "rgb(0, 128, 0)");
rect.setAttribute("fill", "url(#reference)");
shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "url(#reference)");
// Reset to green.
rect.setAttribute("fill", "green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "#008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "rgb(0, 128, 0)");
rect.setAttribute("fill", "url(#reference) green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "url(#reference) #008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "url(#reference) rgb(0, 128, 0)");
// Reset to green.
rect.setAttribute("fill", "green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "#008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).fill", "rgb(0, 128, 0)");
// Testing 'stroke'
@@ -69,50 +69,50 @@ shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke"
// Set the stroke color to green.
rect.setAttribute("stroke", "green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "#008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "rgb(0, 128, 0)");
// Set following colors should be invalid.
rect.setAttribute("stroke", "f00");
shouldBeNull("document.defaultView.getComputedStyle(rect, null).stroke");
// Reset to green.
rect.setAttribute("stroke", "green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "#008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "rgb(0, 128, 0)");
rect.setAttribute("stroke", "ff00");
shouldBeNull("document.defaultView.getComputedStyle(rect, null).stroke");
// Reset to green.
rect.setAttribute("stroke", "green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "#008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "rgb(0, 128, 0)");
rect.setAttribute("stroke", "ff0000");
shouldBeNull("document.defaultView.getComputedStyle(rect, null).stroke");
// Reset to green.
rect.setAttribute("stroke", "green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "#008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "rgb(0, 128, 0)");
rect.setAttribute("stroke", "ff00");
shouldBeNull("document.defaultView.getComputedStyle(rect, null).stroke");
// Reset to green.
rect.setAttribute("stroke", "green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "#008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "rgb(0, 128, 0)");
rect.setAttribute("stroke", "");
shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "none");
// Reset to green.
rect.setAttribute("stroke", "green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "#008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "rgb(0, 128, 0)");
rect.setAttribute("stroke", "url(#reference)");
shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "url(#reference)");
// Reset to green.
rect.setAttribute("stroke", "green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "#008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "rgb(0, 128, 0)");
rect.setAttribute("stroke", "url(#reference) green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "url(#reference) #008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "url(#reference) rgb(0, 128, 0)");
// Reset to green.
rect.setAttribute("stroke", "green");
-shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "#008000");
+shouldBeEqualToString("document.defaultView.getComputedStyle(rect, null).stroke", "rgb(0, 128, 0)");
// Testing 'color'
« no previous file with comments | « LayoutTests/svg/css/rect-system-color-expected.txt ('k') | LayoutTests/svg/css/svg-attribute-parser-mode-expected.txt » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698